@@ -1,6 +1,3 @@
-"""
-git add . && git commit -m "Options" && git push &&  pip install git+ssh://git@gitlab.compute.dtu.dk/tuhe/unitgrade.git --upgrade
-"""
 import numpy as np
 import sys
 import re
@@ -13,7 +10,6 @@ import io
 from unittest.runner import _WritelnDecorator
 from typing import Any
 import inspect
-import textwrap
 import colorama
 from colorama import Fore
 from functools import _make_key, RLock
@@ -97,20 +93,6 @@ class Capturing2(Capturing):
         self.numbers = numbers
 
 
-# @classmethod
-# class OrderedClassMembers(type):
-#     def __prepare__(self, name, bases):
-#         assert False
-#         return collections.OrderedDict()
-#
-#     def __new__(self, name, bases, classdict):
-#         ks = list(classdict.keys())
-#         for b in bases:
-#             ks += b.__ordered__
-#         classdict['__ordered__'] = [key for key in ks if key not in ('__module__', '__qualname__')]
-#         return type.__new__(self, name, bases, classdict)
-
-
 class Report:
     title = "report title"
     version = None
@@ -270,17 +252,9 @@ class ActiveProgress():
 def dprint(first, last, nL, extra = "", file=None, dotsym='.', color='white'):
     if file == None:
         file = sys.stdout
-
-    # ss = self.item_title_print
-    # state = "PASS" if success else "FAILED"
     dot_parts = (dotsym * max(0, nL - len(last) - len(first)))
-    # if self.show_progress_bar or True:
     print(first + dot_parts, end="", file=file)
-    # else:
-    # print(dot_parts, end="", file=self.cc.file)
     last += extra
-    # if tsecs >= 0.5:
-    #     state += " (" + str(tsecs) + " seconds)"
     print(last, file=file)
 
 
@@ -412,8 +386,7 @@ def get_hints(ss):
         h = hints[j]
         ss = ss[ss.lower().find(h) + len(h) + 1:]
         ss = "\n".join([l for l in ss.split("\n") if not l.strip().startswith(":")])
-        ss = textwrap.dedent(ss)
-        ss = ss.strip()
+        ss = textwrap.dedent(ss).strip()
         return ss
     except Exception as e:
         print("bad hints", ss, e)
@@ -473,10 +446,8 @@ class UTestCase(unittest.TestCase):
                         s = f.read()
                     lines = s.splitlines()
                     garb = 'GARBAGE'
-
                     lines2 = snipper_main.censor_code(lines, keep=True)
                     assert len(lines) == len(lines2)
-
                     for l in data.contexts_by_lineno(file):
                         if lines2[l].strip() == garb:
                             if self.cache_id() not in self._report.covcache:
@@ -712,4 +683,4 @@ def methodsWithDecorator(cls, decorator):
             if maybeDecorated.decorator == decorator:
                 print(maybeDecorated)
                 yield maybeDecorated
-# 817
+# 817, 705
\ No newline at end of file
